<div align="center">
  <h1>File Binary</h1>
</div>

[![PyPI Latest Release](https://img.shields.io/pypi/v/pandas.svg)](https://pypi.org/project/file-binary)

---
### What is it ?

**File Binary** is a package with some tools to help you with binary files

### How to install
```py
pip install file-binary
```
### How to use

```py
from binary_file import fb
```